'''Simple data loader module.

Loads data files from the "data" directory shipped with a game.

Enhancing this to handle caching etc. is left as an exercise for the reader.

Note that pyglet users should probably just add the data directory to the
pyglet.resource search path.
'''

import os
from kivy.core.image import ImageLoader
from kivy.core.audio import SoundLoader

data_py = os.path.abspath(os.path.dirname(__file__))
data_dir = os.path.normpath(os.path.join(data_py, '..', 'data'))
loader = ImageLoader()
soundloader = SoundLoader()


def filepath(filename):
    '''Determine the path to a file in the data directory.
    '''
    filename = os.path.join(*filename.split('/'))
    return os.path.join(data_dir, filename)


def load(filename, mode='rb'):
    '''Open a file in the data directory.

    "mode" is passed as the second arg to open().
    '''
    return open(filepath(filename), mode)


def load_image(filename):
    '''Load an image into a kivy texture. We rely on kivy's caching
       infrastructure'''
    return loader.load(filepath(filename))


def load_sound(filename):
    return soundloader.load(filepath(filename))
